==> igniteui-angular-charts-18.1.1.tgz: package/esm2015/lib/DomainChartPlotAreaPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, Point_$type, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DomainChartPlotAreaPointerEventArgs = /*@__PURE__*/ (() => {
    class DomainChartPlotAreaPointerEventArgs extends Base {
        constructor(a, b) {
            super();
            this.b = { $type: Point_$type, x: NaN, y: NaN };
            this._plotAreaPosition = null;
            this.a = null;
            this.a = a;
            this.plotAreaPosition = b;
        }
        get plotAreaPosition() {
            return this._plotAreaPosition;
        }
        set plotAreaPosition(a) {
            this._plotAreaPosition = a;
        }
        get chartPosition() {
            if (isNaN_(this.b.x) && isNaN_(this.b.y)) {
                this.b.x = this.plotAreaPosition.x - this.a.v0.left;
                this.b.y = this.plotAreaPosition.y - this.a.v0.top;
            }
            return this.b;
        }
    }
    DomainChartPlotAreaPointerEventArgs.$t = markType(DomainChartPlotAreaPointerEventArgs, 'DomainChartPlotAreaPointerEventArgs');
    return DomainChartPlotAreaPointerEventArgs;
})();

==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/DomainChartPlotAreaPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, Point_$type, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DomainChartPlotAreaPointerEventArgs = /*@__PURE__*/ (() => {
    class DomainChartPlotAreaPointerEventArgs extends Base {
        constructor(a, b) {
            super();
            this.b = { $type: Point_$type, x: NaN, y: NaN };
            this._plotAreaPosition = null;
            this.a = null;
            this.a = a;
            this.plotAreaPosition = b;
        }
        get plotAreaPosition() {
            return this._plotAreaPosition;
        }
        set plotAreaPosition(a) {
            this._plotAreaPosition = a;
        }
        get chartPosition() {
            if (isNaN_(this.b.x) && isNaN_(this.b.y)) {
                this.b.x = this.plotAreaPosition.x - this.a.wk.left;
                this.b.y = this.plotAreaPosition.y - this.a.wk.top;
            }
            return this.b;
        }
    }
    DomainChartPlotAreaPointerEventArgs.$t = markType(DomainChartPlotAreaPointerEventArgs, 'DomainChartPlotAreaPointerEventArgs');
    return DomainChartPlotAreaPointerEventArgs;
})();
